The code below represents 2" hours of head scratching in an attempt to
create a routine that will automatically re-sequence records in CoEdit mode
in an embedded multi-record form.

It's part of an application I am developing to create and maintain engineering
workshop manufacturing layouts.

The user first creates a header record and then DownImages to the multi-record
form to enter the operations. This table is keyed on the [Layout_No] and
[Layout_Seq_No] from the master table plus the [DOp_Number] in the detail
table.

The first time into the detail a new [DOp_Number] of 10 is assigned and each
time the user elects to add an operation, [DOp_number] is incremented by 10.
Thus ops will go 10,20,30 etc.  This is fine until the user realises he has
made a mistake and needs to enter an op between 20 & 30.

Creating the new record is not a problem - move the cursor to the record
below where the new one will go and press [Ins]. Now the fun starts. In order
to get the record in, the current value of the [DOp_number] is trapped to a
variable and then decremented by 5. This is used as the [DOp_number] for the 
new record. 

So, [DOp_number] is 30, press [Ins], blank line opens new [DOp_number]
is assigned 30-5 = 25. Ok, so far.

Before the user is let loose on the rest of the record I had to find a way of
resequencing the value of all the [DOp_number] fields in the image. Hence
the code below.

All the other ways I tried resulted in the existing records getting out of
sequence - I wasn't deleting them after assigning the new number in the
1000 range.

All this works but I'm sure there is an easier way. If not I offer it as
an example for anyone to use.


John Jamieson


   Message "ReSequencing..."
   Imagerights
   Home

   startop=1000                     ;move start operation out of range
   CopyToArray thisrec              ;copy first rec to array and assign
   thisrec["DOp_Number"]=startop    ;op number the value of startop

   While [Dop_Number]<1000          ;as long as op number is less
      Ins                           ;than 1000 scan the records and
      CopyFromArray thisrec         ;copy the contents of the array
      Postrecord                    ;into a new record with the op number
      startop=startop+10            ;incremented by 10 each time.
      Down                          ;the records are thus numbered
      CopyToArray thisrec           ;1010,1020,1030 etc up to the number of
      thisrec["DOp_Number"]=startop ;records in the current image
   EndWhile                         ;

   Home                             ;return to the top of the image set
   While [DOp_Number]<1000          ;and delete the existing entries
      Del                           ;
   EndWhile                         ;

   opnumber=10                      ;reset the op number to 10 and
   Scan                             ;scan the image set renumbering
      [Dop_Number]=opnumber         ;op number to 10,20,30 etc
      opnumber=opnumber+10          ;
   Endscan

   opnumber=[Dop_Number]+10         ;whilst at the end of the image set
                                    ;get the last op number and increment
                                    ;by 10

   Moveto [DWork_centre]            ;make sure we are on the record
   Scan for IsBlank([])             ;just created (if it's an INS)
      [DStandard_Time]="00:00"      ;set the standard time to 0
      Quitloop                      ;and leave the loop
   Endscan

   Message ""
   Return                           ;return ready to complete the records
